<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-medias?lang_cible=eo
// ** ne pas modifier le fichier **

return [

	// M
	'medias_description' => 'Mastrumado de ĉiuspecaj dokumentoj de SPIP',
	'medias_slogan' => 'Mastrumado de ĉiuspecaj dokumentoj en SPIP',
];
